@@ -210,7 +210,7 @@ class SixfabPower:
             "1" for SUCCESS, "2" for FAIL
         """
 
-        temp = self.getSystemTemp()
+        temp = self.get_system_temp()
         tempInt = int(temp * 100)
 
         command.create_set_command(command.PROTOCOL_COMMAND_GET_SYSTEM_TEMP, tempInt, 4)
@@ -1471,8 +1471,12 @@ class SixfabPower:
         # Calculate packet count
         f = open(firmware_file, "rb")
         all_data = f.read()
-        packet_count = int(len(all_data) / packet_size) + 1
         leap_packet_size = len(all_data) % packet_size
+        packet_count = int(len(all_data) / packet_size) + 1
+        
+        if leap_packet_size == 0:
+             packet_count = int(len(all_data) / packet_size)
+
         f.close()
 
         # open file
@@ -1536,15 +1540,15 @@ class SixfabPower:
 
                     # if final packet comes
                     if requesting_packet_id == 0xFFFF:
-                        print("FIRMWARE UPDATE SUCCESSFULLY ENDED")
+                        print("Firmware packages are being writen to flash...")
+                        print("Please wait until the application starts!")
                         self.reset_mcu()
-                        yield Definition.SET_OK
                         return
                 except:
                     raise ValueError("None Object Exception")
 
         # if firmware update doesn't ended succesfully
-        yield Definition.SET_FAILED
+        raise RuntimeError("Unidentified Runtime Exception")
 
     def clear_program_storage(self, timeout=500):
         """
@@ -1600,3 +1604,107 @@ class SixfabPower:
 
         command.create_command(command.PROTOCOL_COMMAND_RESET_MCU_FOR_BOOT_UPDATE)
         command.send_command()
+
+    
+    def get_lpm_status(self, timeout=RESPONSE_DELAY):
+        """
+        Function for getting low power mode status
+        
+        Parameters
+        -----------
+        timeout : int (optional)
+            timeout while receiving the response (default is RESPONSE_DELAY)
+
+        Returns
+        ------- 
+        status : int
+            "1" for LPM ENABLED, "2" for LPM DISABLED 
+        """
+
+        command.create_command(command.PROTOCOL_COMMAND_GET_LOW_POWER_MODE)
+        command.send_command()
+        delay_ms(timeout)
+        raw = command.receive_command(COMMAND_SIZE_FOR_UINT8)
+
+        status = raw[PROTOCOL_HEADER_SIZE]
+        return status
+
+
+    def get_edm_status(self, timeout=RESPONSE_DELAY):
+        """
+        Function for getting easy deployment mode status
+        
+        Parameters
+        -----------
+        timeout : int (optional)
+            timeout while receiving the response (default is RESPONSE_DELAY)
+
+        Returns
+        ------- 
+        status : int
+            "1" for EDM ENABLED, "2" for EDM DISABLED 
+        """
+
+        command.create_command(command.PROTOCOL_COMMAND_GET_EASY_DEPLOYMENT_MODE)
+        command.send_command()
+        delay_ms(timeout)
+        raw = command.receive_command(COMMAND_SIZE_FOR_UINT8)
+
+        status = raw[PROTOCOL_HEADER_SIZE]
+        return status
+
+
+    def set_lpm_status(self, status, timeout=RESPONSE_DELAY):
+        """
+        Function for setting low power mode status
+        
+        Parameters
+        -----------
+        status : int
+            "1" for ENABLED, "2" for DISABLED
+        timeout : int (optional)
+            timeout while receiving the response (default is RESPONSE_DELAY)
+
+        Returns
+        ------- 
+        result : int
+            "1" for SET OK, "2" for SET FAILED
+        """
+
+        command.create_set_command(
+            command.PROTOCOL_COMMAND_SET_LOW_POWER_MODE, status, 1
+        )
+        command.send_command()
+        delay_ms(timeout)
+        raw = command.receive_command(COMMAND_SIZE_FOR_UINT8)
+
+        status = raw[PROTOCOL_HEADER_SIZE]
+        return status
+
+
+    def set_edm_status(self, status, timeout=RESPONSE_DELAY):
+        """
+        Function for setting easy deployment mode status
+        
+        Parameters
+        -----------
+        status : int
+            "1" for ENABLED, "2" for DISABLED
+        timeout : int (optional)
+            timeout while receiving the response (default is RESPONSE_DELAY)
+
+        Returns
+        ------- 
+        result : int
+            "1" for SET OK, "2" for SET FAILED
+        """
+
+        command.create_set_command(
+            command.PROTOCOL_COMMAND_SET_EASY_DEPLOYMENT_MODE, status, 1
+        )
+        command.send_command()
+        delay_ms(timeout)
+        raw = command.receive_command(COMMAND_SIZE_FOR_UINT8)
+
+        status = raw[PROTOCOL_HEADER_SIZE]
+        return status
